prove_circuit

Function prove_circuit 

pub fn prove_circuit<F: Halo2FFTFriendlyField, Tr: TranscriptSponge<F>>(
    provable_circuit: &ProvableCircuit<F>,
    transcript_writer: &mut TranscriptWriter<F, Tr>,
) -> Result<Vec<Claim<F>>>
Assumes that the inputs have already been added to the transcript (if necessary). Returns the vector of claims on the input layers.